@@ -14,13 +14,11 @@ import pymatgen
 import warnings
 import torch_geometric.data
 from tqdm import tqdm
-from typing import Union
-from typing import Tuple
+from typing import Union, Tuple
 from pymatgen.core.structure import Structure
 from ailca.core.env import *
 from ailca.chem.base import atom_nums
-from ailca.data.base import Data
-from ailca.data.base import Dataset
+from ailca.data.base import Data, Dataset
 
 
 def rbf(data: torch.Tensor,
