@@ -14,8 +14,7 @@ from tqdm import tqdm
 from chemparse import parse_formula
 from ailca.core.env import *
 from ailca.chem.base import atom_nums
-from ailca.data.base import Data
-from ailca.data.base import Dataset
+from ailca.data.base import Data, Dataset
 
 
 def get_form_vec(form: str,
