@@ -11,8 +11,7 @@ import pandas
 from tqdm import tqdm
 from PIL import Image
 from ailca.core.env import *
-from ailca.data.base import Data
-from ailca.data.base import Dataset
+from ailca.data.base import Data, Dataset
 
 
 def get_image_data(path_img_file: str) -> torch.Tensor:
