@@ -4,15 +4,9 @@ from typing import Union
 from torch.utils.data import DataLoader
 from torch_geometric.data import Batch
 from torch_geometric.nn import Sequential
-from torch_geometric.nn import LayerNorm
-from torch_geometric.nn import GCNConv
-from torch_geometric.nn import GATConv
-from torch_geometric.nn import GINConv
-from torch_geometric.nn import NNConv
-from torch_geometric.nn import CGConv
-from torch_geometric.nn import TransformerConv
-from torch_geometric.nn import global_mean_pool
-from torch_geometric.nn import global_add_pool
+from torch_geometric.nn.norm import LayerNorm
+from torch_geometric.nn.conv import GCNConv, GATConv, GINConv, NNConv, CGConv, TransformerConv
+from torch_geometric.nn.glob import global_mean_pool, global_add_pool
 from ailca.core.sys import is_gpu_runnable
 from ailca.data.base import Dataset
 from ailca.ml.base import PyTorchModel
